@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Red Hat, Inc.
+ * Copyright (c) 2012-2023 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -133,7 +133,14 @@ public class HttpBitbucketServerApiClient implements BitbucketServerApiClient {
   @Override
   public BitbucketUser getUser(String slug, @Nullable String token)
       throws ScmItemNotFoundException, ScmUnauthorizedException, ScmCommunicationException {
-    URI uri = serverUri.resolve("./rest/api/1.0/users/" + slug);
+    URI uri;
+    try {
+      uri = serverUri.resolve("./rest/api/1.0/users/" + slug);
+    } catch (IllegalArgumentException e) {
+      // if the slug contains invalid characters (space for example) then the URI will be invalid
+      throw new ScmCommunicationException(e.getMessage(), e);
+    }
+
     HttpRequest request =
         HttpRequest.newBuilder(uri)
             .headers(
@@ -400,15 +407,11 @@ public class HttpBitbucketServerApiClient implements BitbucketServerApiClient {
   }
 
   private String computeAuthorizationHeader(String requestMethod, String requestUrl)
-      throws ScmUnauthorizedException, ScmCommunicationException {
+      throws ScmCommunicationException {
     try {
       Subject subject = EnvironmentContext.getCurrent().getSubject();
-      String authorizationHeader =
-          authenticator.computeAuthorizationHeader(subject.getUserId(), requestMethod, requestUrl);
-      if (Strings.isNullOrEmpty(authorizationHeader)) {
-        throw buildScmUnauthorizedException();
-      }
-      return authorizationHeader;
+      return authenticator.computeAuthorizationHeader(
+          subject.getUserId(), requestMethod, requestUrl);
     } catch (OAuthAuthenticationException e) {
       throw new ScmCommunicationException(e.getMessage(), e);
     }
